@@ -12,9 +12,10 @@ import logging
 import asyncio
 import royalnet.engineer as engi
 import click
+import datetime
 
 # Internal imports
-from . import magazine
+from . import bullets
 
 # Special global objects
 log = logging.getLogger(__name__)
@@ -29,12 +30,6 @@ class ConsolePDA:
     def __init__(self):
         log.debug(f"Creating new ConsolePDA...")
 
-        log.debug(f"Creating new magazine...")
-        self.mag = magazine.ConsoleMagazine()
-        """
-        The :class:`royalnet.engineer.magazine.Magazine` used by this PDA.
-        """
-
         self.dispenser: t.Optional[engi.Dispenser] = None
         """
         The :class:`royalnet.engineer.dispenser.Dispenser` of this PDA.
@@ -46,20 +41,24 @@ class ConsolePDA:
         :class:`~royalnet.engineer.dispenser.Dispenser`.
         """
 
-    async def run(self) -> t.NoReturn:
+    async def run(self, cycles: t.Union[bool, int] = True) -> t.NoReturn:
         """
-        Run the main loop of the :class:`.ConsolePDA`.
+        Run the main loop of the :class:`.ConsolePDA` for ``cycles`` cycles, or unlimited cycles if the parameter is
+        :data:`True`.
         """
 
-        while True:
+        while cycles:
             message = click.prompt("", type=str, prompt_suffix=">>> ", show_default=False)
-            log.debug(f"Received a new message: {message!r}")
+            log.debug(f"Received a new input: {message!r}")
 
-            log.debug(f"Creating ConsoleMessage from: {message!r}")
-            bullet = self.mag.Message(_text=message)
+            log.debug(f"Creating ConsoleMessageReceived from: {message!r}")
+            projectile = bullets.ConsoleMessageReceived(_text=message, _timestamp=datetime.datetime.now())
 
-            log.debug(f"Putting bullet: {bullet!r}")
-            await self.put_bullet(bullet=bullet)
+            log.debug(f"Putting projectile: {projectile!r}")
+            await self.put_projectile(proj=projectile)
+
+            if isinstance(cycles, int):
+                cycles -= 1
 
     def register_conversation(self, conv: engi.Conversation) -> None:
         """
@@ -96,11 +95,11 @@ class ConsolePDA:
         self.register_conversation(command)
         return command
 
-    async def put_bullet(self, bullet: engi.Bullet) -> None:
+    async def put_projectile(self, proj: engi.Projectile) -> None:
         """
-        Insert a new bullet into the dispenser.
+        Insert a new projectile into the dispenser.
 
-        :param bullet: The bullet to put in the dispenser.
+        :param proj: The projectile to put in the dispenser.
         """
         if not self.dispenser:
             log.debug(f"Dispenser not found, creating one...")
@@ -116,8 +115,8 @@ class ConsolePDA:
         log.debug("Running a event loop cycle...")
         await asyncio.sleep(0)
 
-        log.debug(f"Putting bullet {bullet!r} in dispenser {self.dispenser!r}...")
-        await self.dispenser.put(bullet)
+        log.debug(f"Putting projectile {proj!r} in dispenser {self.dispenser!r}...")
+        await self.dispenser.put(proj)
 
         log.debug("Awaiting another event loop cycle...")
         await asyncio.sleep(0)
